@@ -2,13 +2,15 @@ import logging
 import sys
 from typing import List
 
-from anscenter.app.core.logging import InterceptHandler
+from tqatest.app.core.logging import InterceptHandler
 from loguru import logger
 from starlette.config import Config
 from starlette.datastructures import CommaSeparatedStrings, Secret
 
+package_dir = os.path.dirname(os.path.abspath(__file__))
+envpath = os.path.join(package_dir,'../../.env')
 
-config = Config(".env")
+config = Config(envpath)
 
 API_PREFIX = "/api"
 VERSION = config("VERSION")
