@@ -2,10 +2,9 @@ import os
 import sys
 from typing import List
 from tqatest.app.core.errors import PredictException, ModelLoadException
-# from anscenter.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
+from tqatest.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
 from loguru import logger
 from tqatest.ml.libs import annhub
-from importlib.resources import path
 
 MODEL_NAME = "TrainedModel_c++.ann"
 MODEL_PATH = "ml/model/"
@@ -29,15 +28,13 @@ class MachineLearningModel(object):
         #     logger.error(message)
         #     raise FileNotFoundError(message)
         package_dir = os.path.dirname(os.path.abspath(__file__))
-        thefile = os.path.join(package_dir,'../../ml/model/TrainedModel_c++.ann')
-        print(thefile)
-        # mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
+        path = os.path.join(package_dir,'../../ml/model/TrainedModel_c++.ann')
 
-        self.load_model(thefile)
+        self.load_model(path)
     
-    def load_model(self, mypath : str):
+    def load_model(self, path : str):
         self.model = annhub.ANNHUB(int(MODEL_ID))
-        self.model.LoadWeightFile(mypath)
+        self.model.LoadWeightFile(path)
         if not self.model:
             message = f"Model {MODEL_ID} could not load!"
             logger.error(message)
